=== modified file 'archive-reports'
--- archive-reports	2023-04-25 02:37:39 +0000
+++ archive-reports	2019-04-20 00:23:18 +0000
@@ -22,16 +22,23 @@
 fi
 
 MIRROR="$HOME/mirror/ubuntu"
+MIRROR_RTM="$HOME/mirror/ubuntu-rtm"
+MIRROR_PHONE_OVERLAY="$HOME/mirror/phone-overlay"
 GERMINATE="$HOME/mirror/ubuntu-germinate"
 OUT="$HOME/public_html"
-DEVEL=mantic
-PROPOSED_MIGRATION_SERIES="trusty xenial bionic focal jammy kinetic lunar mantic"
+DEVEL=eoan
+DEVEL_RTM=14.09
+DEVEL_RTM_FACTORY=14.09-factory
+PROPOSED_MIGRATION_SERIES="precise trusty xenial bionic cosmic disco eoan"
+PROPOSED_MIGRATION_SERIES_RTM="14.09 14.09-factory"
 
 mtimes="$(mktemp -d)"
 
 collect_mtimes () {
 	stat -c '%n %Y' \
 		"$MIRROR"/dists/*/Release \
+		"$MIRROR_RTM"/dists/*/Release \
+		"$MIRROR_PHONE_OVERLAY"/dists/*/Release \
 		"$GERMINATE/germinate.output" \
 		"$HOME/extra-germinate/germinate.output" \
 		>"$mtimes/$1" 2>/dev/null || true
@@ -45,8 +52,16 @@
 	[ "$(mtime old "$1")" != "$(mtime new "$1")" ]
 }
 
+is_rtm () {
+	[ -e "$MIRROR_RTM/dists/$1" ]
+}
+
 release_changed () {
-	mtime_changed "$MIRROR/dists/$1/Release"
+	if is_rtm "$1"; then
+		mtime_changed "$MIRROR_RTM/dists/$1/Release"
+	else
+		mtime_changed "$MIRROR/dists/$1/Release"
+	fi
 }
 
 germinate_changed () {
@@ -56,7 +71,7 @@
 
 is_devel () {
 	case $suite in
-	    $DEVEL-proposed)
+	    $DEVEL-proposed|$DEVEL_RTM-proposed|$DEVEL_RTM_FACTORY-proposed)
 		return 0
 		;;
 	    *)
@@ -67,8 +82,12 @@
 
 pm_pending_tests () {
 	local excuses
-	excuses="$HOME/public_html/proposed-migration/$1/update_excuses.html"
-	[ ! -f "$excuses" ] || grep -q "Test in progress" "$excuses"
+	if is_rtm "$1"; then
+		excuses="$HOME/public_html/proposed-migration/ubuntu-rtm/$1/update_excuses.html"
+	else
+		excuses="$HOME/public_html/proposed-migration/$1/update_excuses.html"
+	fi
+	grep -q "Test in progress" "$excuses"
 }
 
 background () {
@@ -94,11 +113,9 @@
 	--exclude gutsy\* --exclude hardy\* --exclude intrepid\* \
 	--exclude jaunty\* --exclude karmic\* --exclude lucid\* \
 	--exclude maverick\* --exclude natty\* --exclude oneiric\* \
-	--exclude precise\* --exclude quantal\* --exclude raring\* \
-	--exclude saucy\* --exclude utopic\* --exclude wily\* \
+	--exclude quantal\* --exclude raring\* --exclude saucy\* \
+	--exclude utopic\* --exclude wily\* \
 	--exclude yakkety\* --exclude zesty\* --exclude artful\* \
-	--exclude cosmic\* --exclude disco\* --exclude eoan\* \
-	--exclude groovy\* --exclude hirsute\* --exclude impish\* \
 	--include Packages\* --include Sources\* --include Release\* \
 	--include udeb.list --include \*\*/installer-\*/current \
 	--include "**/$DEVEL/Contents-*" \
@@ -106,6 +123,23 @@
 	--prune-empty-dirs \
 	ftpmaster.internal::ubuntu-dists/ "$MIRROR/dists/"
 
+mkdir -p "$MIRROR_RTM"
+rsync -aq \
+	--include Packages\* --include Sources\* --include Release\* \
+	--include udeb.list --include \*\*/installer-\*/current \
+	--include "**/$DEVEL_RTM/Contents-*" \
+	--include "**/$DEVEL_RTM_FACTORY/Contents-*" \
+	--include \*/ --exclude \* --delete --delete-excluded \
+	--prune-empty-dirs \
+	bilimbi.canonical.com::ubuntu-rtm-dists/ "$MIRROR_RTM/dists/"
+
+mkdir -p "$MIRROR_PHONE_OVERLAY"
+http_proxy=http://squid.internal:3128/ wget -q --mirror \
+	-nH --cut-dirs=3 -np -R '*index.html*' \
+	-P "$MIRROR_PHONE_OVERLAY" \
+	-X '/*/*/*/*/*/*/i18n' \
+	http://ppa.launchpad.net/ci-train-ppa-service/stable-phone-overlay/ubuntu/dists/
+
 collect_mtimes new
 
 # The $DEVEL-proposed chdist configuration is used by proposed-migration;
@@ -127,32 +161,51 @@
 done
 background_wait chdist_pids
 
+if mtime_changed "$MIRROR/.*/Release" || \
+   mtime_changed "$MIRROR_RTM/.*/Release" || \
+   mtime_changed "$MIRROR_PHONE_OVERLAY/.*/Release"; then
+	background pids run-apt-mirror-snapshot
+fi
+
 pids=
 run_proposed_migration () {
 	DISTRIBUTION=ubuntu SERIES="$1" run-proposed-migration
 }
-
-check_git_uptodate() {
-	cd "$1"
-	git fetch origin -q
-	branch=$(git symbolic-ref --short -q HEAD)
-	[ -z "$(git diff origin/$branch..$branch)" ]
-}
-
 for series in $PROPOSED_MIGRATION_SERIES; do
 	if release_changed "$series" || release_changed "$series-proposed" || \
 	   release_changed "$series-updates" || \
-	   pm_pending_tests "$series" || \
-	   ! check_git_uptodate "$HOME/proposed-migration/data/${series}-proposed/Hints"
-	then
+	   pm_pending_tests "$series"; then
 		background pids run_proposed_migration "$series"
 	fi
 done
 
+run_proposed_migration_rtm () {
+	DISTRIBUTION=ubuntu-rtm SERIES="$1" \
+		B2_CONFIG=/home/ubuntu-archive/proposed-migration/britney-rtm.conf \
+		B2_CONFIG_NOBREAKALL=/home/ubuntu-archive/proposed-migration/britney_nobreakall-rtm.conf \
+		run-proposed-migration
+}
+for series in $PROPOSED_MIGRATION_SERIES_RTM; do
+	if release_changed "$series" || release_changed "$series-proposed" || \
+	   release_changed "$series-updates" || \
+	   pm_pending_tests "$series"; then
+		background pids run_proposed_migration_rtm "$series"
+	fi
+done
+
+# Both update-transitions and run-britney need this.
+rsync -aq --delete --prune-empty-dirs \
+	"$MIRROR/dists/" \
+	"/srv/chroots/trusty-transitions/srv/transitions/mirror/ubuntu/dists/"
+
 if release_changed "$DEVEL-proposed"; then
 	background pids update-transitions
 fi
 
+if release_changed "$DEVEL"; then
+	background pids run-britney
+fi
+
 # Now update all the other chdist configurations, and wait for that to
 # finish before doing anything else.
 chdist_pids=
@@ -176,13 +229,23 @@
 	background pids cron.NBS
 fi
 
+nbs_rtm () {
+	DISTRIBUTION=ubuntu-rtm RELEASE="$1" \
+		OUTDIR="$HOME/public_html/NBS-RTM" \
+		OUTFILE="$HOME/public_html/nbs-rtm.html" \
+		cron.NBS
+}
+if release_changed "$DEVEL_RTM"; then
+	background pids nbs_rtm "$DEVEL_RTM"
+fi
+
 if release_changed "$DEVEL" || release_changed "$DEVEL-proposed"; then
 	# Do an extra germinate run so that we can run component-mismatches
 	# against -proposed.  (We can't do this as part of LP archive
 	# publishing because that would probably cause us to break our
 	# 30-minute window.)
 	background pids \
-		env PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}$HOME/ubuntu-archive-tools:$HOME/germinate" \
+		env PYTHONPATH="$HOME/ubuntu-archive-tools:$HOME/germinate" \
 		extra-germinate -o "$HOME/extra-germinate" ubuntu
 fi
 
@@ -197,10 +260,12 @@
 collect_mtimes new
 
 if germinate_changed; then
-	# Check for the marker line emitted by lp:ubuntu-archive-publishing
-	# at the end of the run.  If we don't find this, then we've rsynced
-	# partial output and should try again later.
-	if fgrep -q 'Germination complete.' "$GERMINATE/germinate.output"; then
+	# Give germinate a two minute window to stop spewing to output
+	# and assume it's finished, this should be more than enough time,
+	# given that it outputs nearly constantly when run, and completes
+	# in under three minutes, on average
+	NEW_GERMINATE_MTIME="$(mtime new "$GERMINATE/germinate.output")"
+	if [ $(($(date +%s) - $NEW_GERMINATE_MTIME)) -gt 120 ]; then
 		component_mismatches () {
 			local name="$1"
 			shift
@@ -208,14 +273,13 @@
 				-d "$OUT/$name.dot" -o "$OUT/$name.txt.new" \
 				--html-output-file "$OUT/$name.html" \
 				--csv-file "$OUT/$name.csv" \
-				--exclude "community-maas" \
 				"$@"
 			if [ "$name" = component-mismatches ]; then
 				process-component-mismatches-diff \
 					"$OUT/$name.txt" "$OUT/$name.txt.new"
 			fi
 			mv "$OUT/$name.txt.new" "$OUT/$name.txt"
-			dot -Tsvg -o "$OUT/$name.svg" "$OUT/$name.dot"
+			dot -Tsvg -Gdpi=55 -o "$OUT/$name.svg" "$OUT/$name.dot"
 		}
 		background pids component_mismatches component-mismatches
 		background pids component_mismatches component-mismatches-proposed \
@@ -231,5 +295,8 @@
 			--csv-file "$OUT/architecture-mismatches.csv"
 
 		background_wait pids
+	else
+		# Artifically bump $GERMINATE/germinate.output into the past
+		touch -d @$(($NEW_GERMINATE_MTIME - 1)) $GERMINATE/germinate.output
 	fi
 fi

=== modified file 'auto-accept'
--- auto-accept	2023-04-25 02:37:39 +0000
+++ auto-accept	2019-04-20 00:23:18 +0000
@@ -1,17 +1,17 @@
-#!/usr/bin/python3
+#!/usr/bin/python
 import subprocess
 import sys
 import time
 
 from launchpadlib.launchpad import Launchpad
 
-SERIES = "mantic"
+SERIES = "eoan"
 POCKET = "Proposed"
 QUEUE = "Unapproved"
-SEED_WHITELIST = []
-PACKAGESET_WHITELIST = {"i386-excludes", "i386-whitelist"}
+SEED_WHITELIST = ["ubuntu-desktop-next"]
 SEEDED_IN_UBUNTU = "/home/ubuntu-archive/ubuntu-dev-tools/seeded-in-ubuntu"
-PACKAGE_WHITELIST = []
+PACKAGE_WHITELIST = ["upstart-app-launch", "click", "click-apparmor",
+                     "apparmor-easyprof-ubuntu", "ubuntuone-credentials"]
 
 DEBUG = 0
 if len(sys.argv) > 1 and sys.argv[1] == "debug":
@@ -27,9 +27,6 @@
 # Get the series
 series = ubuntu.getSeries(name_or_version=SERIES)
 
-if series.status not in ('Active Development', 'Pre-release Freeze'):
-    print("Series no longer in active development; not accepting packages")
-    sys.exit(1)
 
 # Process the packages
 for pkg in series.getPackageUploads(status=QUEUE, pocket=POCKET,
@@ -48,7 +45,6 @@
             distroseries=series, sourcepackagename=pkg.package_name):
         package_sets.add(pkgset.name)
 
-    package_sets -= PACKAGESET_WHITELIST
     if package_sets:
         if DEBUG:
             print("Skipping '%s' because it's in the following packagesets: %s" %

=== modified file 'chdist'
--- chdist	2019-10-18 09:32:04 +0000
+++ chdist	2011-11-24 13:05:00 +0000
@@ -136,8 +136,6 @@
 use Cwd qw(abs_path cwd);
 use Dpkg::Version;
 use Pod::Usage;
-# Stop warning about 'when' and 'given':
-no warnings 'experimental::smartmatch';
 
 # Redefine Pod::Text's cmd_i so pod2usage converts I<...> to <...> instead of
 # *...*

=== removed file 'clean-eol-series'
--- clean-eol-series	2020-04-10 00:56:58 +0000
+++ clean-eol-series	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-#!/bin/sh
-set -e
-
-# Automate the task of cleaning up files related to a release once it's
-# EOL.
-
-DIST="$1"
-
-if [ -z "$DIST" ]; then
-	echo "Usage: $0 DIST"
-	exit 1
-fi
-
-BASEDIR=/home/ubuntu-archive
-rm -rfv "$BASEDIR"/proposed-migration/data/"$DIST" \
-	"$BASEDIR"/proposed-migration/data/"$DIST"-proposed \
-	"$BASEDIR"/proposed-migration/output/"$DIST" \
-	"$BASEDIR"/public_html/germinate-output/*."$DIST" \
-	"$BASEDIR"/public_html/proposed-migration/"$DIST" \
-	"$BASEDIR"/public_html/proposed-migration/"$DIST"_uninst_full.txt \
-	"$BASEDIR"/public_html/proposed-migration/"$DIST"_uninst.txt \
-	"$BASEDIR"/public_html/proposed-migration/update_output/"$DIST"

=== modified file 'compare-archives'
--- compare-archives	2023-03-16 22:01:08 +0000
+++ compare-archives	2016-10-18 10:01:43 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/python
 
 from __future__ import print_function
 

=== modified file 'extra-germinate'
--- extra-germinate	2023-03-16 22:01:08 +0000
+++ extra-germinate	2014-06-10 16:20:34 +0000
@@ -1,4 +1,4 @@
-#! /usr/bin/python3
+#! /usr/bin/python
 
 # Based on lib/lp/archivepublisher/scripts/generate_extra_overrides.py from
 # Launchpad, which is:

=== modified file 'find-rcbuggy-problem-packages'
--- find-rcbuggy-problem-packages	2020-07-30 10:59:13 +0000
+++ find-rcbuggy-problem-packages	2019-09-18 13:15:59 +0000
@@ -248,12 +248,7 @@
 
 def main():
     print("loading data")
-    if args.ubuntu_excuses.endswith('.xz'):
-        import lzma
-        excuses_opener = lzma.open
-    else:
-        excuses_opener = open
-    with excuses_opener(args.ubuntu_excuses) as fp:
+    with open(args.ubuntu_excuses) as fp:
         ubuntu_excuses = yaml.load(fp, Loader=yaml.CSafeLoader)
     with open(args.ubuntu_update_output) as fp:
         bin_pkg_arch_to_blocked_src_pkgs = extract_bin_pkg_arch_to_blocked_src_pkgs(fp)

=== removed file 'generate-team-bzr'
--- generate-team-bzr	2023-04-03 19:40:08 +0000
+++ generate-team-bzr	1970-01-01 00:00:00 +0000
@@ -1,136 +0,0 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-
-# Copyright (C) 2018 Canonical Ltd
-
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# A copy of the GNU General Public License version 2 is in LICENSE.
-
-import apt_pkg
-import argparse
-import atexit
-from collections import defaultdict
-from datetime import datetime
-import gzip
-import json
-import os
-import re
-import shutil
-import tempfile
-from textwrap import dedent
-from urllib.request import urlopen
-
-import attr
-from jinja2 import Environment, FileSystemLoader
-import yaml
-
-env = Environment(
-    loader=FileSystemLoader(os.path.dirname(os.path.abspath(__file__)) + '/templates'),
-    autoescape=True,
-    extensions=['jinja2.ext.i18n'],
-)
-env.install_null_translations(True)
-
-tempdir = None
-
-
-# copied from component-mismatches
-def ensure_tempdir():
-    global tempdir
-    if not tempdir:
-        tempdir = tempfile.mkdtemp(prefix='component-mismatches')
-        atexit.register(shutil.rmtree, tempdir)
-
-
-# copied from component-mismatches
-def decompress_open(tagfile):
-    ensure_tempdir()
-    decompressed = tempfile.mktemp(dir=tempdir)
-    fin = gzip.GzipFile(filename=tagfile)
-    with open(decompressed, 'wb') as fout:
-        fout.write(fin.read())
-    return open(decompressed, 'r')
-
-
-# copied from generate-team-p-m
-def get_subscribers_json(packages, subscribers_json):
-    if subscribers_json is None:
-        j = urlopen("https://ubuntu-archive-team.ubuntu.com/package-team-mapping.json")
-    else:
-        j = open(subscribers_json, 'rb')
-    with j:
-        team_to_packages = json.loads(j.read().decode('utf-8'))
-    package_to_teams = {}
-    for team, team_packages in team_to_packages.items():
-        for package in team_packages:
-            if package in packages:
-                package_to_teams.setdefault(package, []).append(team)
-    return package_to_teams
-
-
-def packages_with_bzr_repos(options):
-    pkgs = {}
-    for component in options.components.split(','):
-        sources_path = "%s/dists/%s/%s/source/Sources.gz" % (
-            options.archive_dir, options.suite, component)
-        for section in apt_pkg.TagFile(decompress_open(sources_path)):
-            if 'Package' in section and 'Vcs-Bzr' in section:
-                pkgs[section['Package']] = section['Vcs-Bzr']
-    return pkgs
-
-
-def repo_url(repo):
-    return re.sub('^lp:', 'https://code.launchpad.net/', repo)
-
-
-def main():
-    parser = argparse.ArgumentParser()
-    parser.add_argument('--archive-dir', action='store', default=os.path.expanduser("~/mirror/ubuntu"))
-    parser.add_argument('--components', action='store', default="main,restricted,universe,multiverse")
-    parser.add_argument('--suite', action='store')
-    parser.add_argument('--subscribers-json', action='store')
-    parser.add_argument('output')
-    args = parser.parse_args()
-
-    pkgs = packages_with_bzr_repos(args)
-
-    print("getting subscribers")
-    subscribers = get_subscribers_json(set(pkgs.keys()), args.subscribers_json)
-    for p in set(pkgs.keys()):
-        if p not in subscribers:
-            subscribers[p] = ['unknown']
-
-    all_teams = set()
-    team_to_pkgs = defaultdict(list)
-    for package, teams in subscribers.items():
-        all_teams |= set(teams)
-        for team in teams:
-            team_to_pkgs[team].append(package)
-
-    team_to_attn_count = {}
-    for team, packages in team_to_pkgs.items():
-        team_to_attn_count[team] = len(packages)
-        team_to_pkgs[team] = [(package, repo_url(pkgs[package])) for package in sorted(packages)]
-
-    print("rendering")
-    t = env.get_template('team-report-bzr.html')
-    now = datetime.utcnow()
-    with open(args.output, 'w', encoding='utf-8') as fp:
-        fp.write(t.render(
-            all_teams=all_teams,
-            now="%s UTC" % now.strftime("%Y-%m-%d %H:%M:%S"),
-            team_to_pkgs=team_to_pkgs,
-            team_to_attn_count=team_to_attn_count))
-
-
-if __name__ == '__main__':
-    main()

=== modified file 'generate-team-p-m'
--- generate-team-p-m	2023-04-03 19:40:08 +0000
+++ generate-team-p-m	2018-12-19 02:42:03 +0000
@@ -18,17 +18,14 @@
 import argparse
 from collections import defaultdict, OrderedDict
 import datetime
-import time
 import json
 import os
 import threading
 from urllib.request import urlopen
-import urllib.error
 
 import attr
 from jinja2 import Environment, FileSystemLoader
 import yaml
-import lzma
 
 env = Environment(
     loader=FileSystemLoader(os.path.dirname(os.path.abspath(__file__)) + '/templates'),
@@ -125,7 +122,7 @@
 
 def get_subscribers_json(packages, subscribers_json):
     if subscribers_json is None:
-        j = urlopen("https://ubuntu-archive-team.ubuntu.com/package-team-mapping.json")
+        j = urlopen("http://people.canonical.com/~ubuntu-archive/package-team-mapping.json")
     else:
         j = open(subscribers_json, 'rb')
     with j:
@@ -191,9 +188,6 @@
     waiting = attr.ib(default=None) # [(source_package_name, arches)]
     data = attr.ib(default=None) # data for package_in_proposed
     unsatdepends = attr.ib(default=None) # [string]
-    unsatbuilddep = attr.ib(default=None) # [string]
-    brokenbin = attr.ib(default=None) # [string]
-    componentmismatch = attr.ib(default=None) # [string]
 
     _age = attr.ib(default=None)
 
@@ -211,10 +205,7 @@
         if self._age is not None:
             return self._age
         else:
-            try:
-                return self.data["policy_info"]["age"]["current-age"]
-            except KeyError:
-                return -1
+            return self.data["policy_info"]["age"]["current-age"]
 
     @age.setter
     def age(self, val):
@@ -243,16 +234,9 @@
 
     print("fetching yaml")
     if args.excuses_yaml:
-        if args.excuses_yaml.endswith('.xz'):
-            yaml_text = lzma.open(args.excuses_yaml)
-        else:
-            yaml_text = open(args.excuses_yaml)
+        yaml_text = open(args.excuses_yaml).read()
     else:
-        try:
-            yaml_text = lzma.open(urlopen("https://ubuntu-archive-team.ubuntu.com/proposed-migration/update_excuses.yaml.xz"))
-        except urllib.error.HTTPError as e:
-            print("Reading fallback yaml (%s)" % e)
-            yaml_text = urlopen("https://ubuntu-archive-team.ubuntu.com/proposed-migration/update_excuses.yaml")
+        yaml_text = urlopen("https://people.canonical.com/~ubuntu-archive/proposed-migration/update_excuses.yaml").read()
     print("parsing yaml")
     # The CSafeLoader is ten times faster than the regular one
     excuses = yaml.load(yaml_text, Loader=yaml.CSafeLoader)
@@ -264,17 +248,10 @@
         # Missing component means main
         if item.get('component', 'main') not in components:
             continue
-        prob = Problem(kind='package-in-proposed', data=defaultdict(dict, item), package_in_proposed=source_package_name)
+        prob = Problem(kind='package-in-proposed', data=item, package_in_proposed=source_package_name)
         in_proposed_packages[source_package_name] = prob
         prob.regressions = []
         prob.waiting = []
-        prob.componentmismatch = []
-        # The verdict entries are not items to list on the report
-        for policy in ['autopkgtest', 'update-excuse', 'block-bugs']:
-            try:
-                del item['policy_info'][policy]['verdict']
-            except KeyError:
-                pass
         if 'autopkgtest' in item['reason']:
             for package, results in sorted(item['policy_info']['autopkgtest'].items()):
                 regr_arches = []
@@ -292,32 +269,17 @@
                     prob.regressions.append(regr)
                 if wait_arches:
                     prob.waiting.append((package + ": " + ", ".join(wait_arches)))
-        if 'depends' in item['reason']:
-            for l in item['excuses']:
-                if 'cannot depend on' in l:
-                    prob.componentmismatch.append(l)
         if 'dependencies' in item and 'unsatisfiable-dependencies' in item['dependencies']:
                 unsatd = defaultdict(list)
                 for arch, packages in item['dependencies']['unsatisfiable-dependencies'].items():
                     for p in packages:
                         unsatd[p].append(arch)
                 prob.unsatdepends = ['{}: {}'.format(p, ', '.join(sorted(arches))) for p, arches in sorted(unsatd.items())]
-        if 'policy_info' in item:
-            if 'build-depends' in item['policy_info'] and 'unsatisfiable-arch-build-depends' in item['policy_info']['build-depends']:
-                    unsatdbd = defaultdict(list)
-                    for arch, packages in item['policy_info']['build-depends']['unsatisfiable-arch-build-depends'].items():
-                        for p in packages:
-                            unsatdbd[p].append(arch)
-                    prob.unsatbuilddep = ['{}: {}'.format(p, ', '.join(sorted(arches))) for p, arches in sorted(unsatdbd.items())]
-            if 'implicit-deps' in item['policy_info']['implicit-deps']:
-                    prob.brokenbin = item['policy_info']['implicit-deps']['implicit-deps']['broken-binaries']
 
     package_to_problems = defaultdict(list)
 
     for problem in in_proposed_packages.values():
-        # nautilus/riscv64 -> nautilus
-        pkg = problem.package_in_proposed.split('/')[0]
-        package_to_problems[pkg].append(problem)
+        package_to_problems[problem.package_in_proposed].append(problem)
         for regression in problem.regressions:
             if regression.blocking not in in_proposed_packages:
                 continue
@@ -344,8 +306,7 @@
     else:
         subscribers = get_subscribers_json(set(package_to_problems), args.subscribers_json)
         for p in set(package_to_problems):
-            pkg = p.split('/')[0]
-            if pkg not in subscribers:
+            if p not in subscribers:
                 subscribers[p] = ['unknown']
 
     all_teams = set()
@@ -369,7 +330,7 @@
             all_teams=all_teams,
             team_to_problems=team_to_problems,
             team_to_attn_count=team_to_attn_count,
-            now=excuses["generated-date"].strftime("%Y.%m.%d %H:%M:%S") + ' ' + time.localtime().tm_zone))
+            now=excuses["generated-date"].strftime("%Y.%m.%d %H:%M:%S")))
     if args.yaml_output:
         team_to_problem_data = {}
         for t, ps in team_to_problems.items():

=== modified file 'process-component-mismatches-diff'
--- process-component-mismatches-diff	2023-04-03 19:40:08 +0000
+++ process-component-mismatches-diff	2012-11-12 00:20:43 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/python
 # (C) 2011 Canonical Ltd.
 # Author: Martin Pitt <martin.pitt@canonical.com>
 # License: GPL-2+
@@ -86,7 +86,7 @@
 promoted, or the reverse dependencies in main need to be dropped:
 
 %s
-Please see https://ubuntu-archive-team.ubuntu.com/component-mismatches.txt
+Please see http://people.canonical.com/~ubuntu-archive/component-mismatches.txt
 for the full report.
 
 Please contact https://launchpad.net/~ubuntu-archive for problems with this
@@ -98,12 +98,12 @@
 addrs = ['ubuntu-release@lists.ubuntu.com']
 msg = MIMEText(r)
 msg['Subject'] = 'New component-mismatches for source universe -> main'
-msg['From'] = 'process-component-mismatches-diff <ubuntu-release@lists.ubuntu.com>'
+msg['From'] = 'process-component-mismatches-diff <martin.pitt@ubuntu.com>'
 msg['To'] = ', '.join(addrs)
 msgstr = msg.as_string()
 
 for addr in addrs:
     s = smtplib.SMTP()
     s.connect()
-    s.sendmail('archive@ubuntu.com', addr, msgstr)
+    s.sendmail('martin.pitt@ubuntu.com', addr, msgstr)
     s.quit()

=== added symlink 'run-autopkgtest'
=== target is '../proposed-migration/code/b2/run-autopkgtest'
=== removed file 'run-autopkgtest'
--- run-autopkgtest	2020-07-15 13:27:14 +0000
+++ run-autopkgtest	1970-01-01 00:00:00 +0000
@@ -1,153 +0,0 @@
-#!/usr/bin/python3
-# Request re-runs of autopkgtests for packages
-
-from datetime import datetime
-import os
-import sys
-import argparse
-import json
-import urllib.parse
-
-import amqplib.client_0_8 as amqp
-
-#my_dir = os.path.dirname(os.path.realpath(sys.argv[0]))
-my_dir = os.path.expanduser('~ubuntu-archive/proposed-migration/code/b2')
-
-
-def parse_args():
-    '''Parse command line arguments'''
-
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-c', '--config',
-                        help='britney config file (default: britney.conf.ubuntu.<series>)')
-    parser.add_argument('-s', '--series', required=True,
-                        help='Distro series name (required).')
-    parser.add_argument('-a', '--architecture', action='append', default=[],
-                        help='Only run test(s) on given architecture name(s). '
-                        'Can be specified multiple times (default: all).')
-    parser.add_argument('--trigger', action='append', default=[],
-                        metavar='SOURCE/VERSION',
-                        help='Add triggering package to request. '
-                        'Can be specified multiple times.')
-    parser.add_argument('--ppa', metavar='LPUSER/PPANAME', action='append',
-                        default=[],
-                        help='Enable PPA for requested test(s). '
-                        'Can be specified multiple times.')
-    parser.add_argument('--env', metavar='KEY=VALUE', action='append',
-                        default=[],
-                        help='List of VAR=value strings. '
-                        'This can be used to influence a test\'s behaviour '
-                        'from a test request. '
-                        'Can be specified multiple times.')
-    parser.add_argument('--test-git',
-                        metavar='URL [branchname]',
-                        help='A single URL or URL branchname. '
-                        'The test will be git cloned from that URL and ran '
-                        'from the checkout. This will not build binary '
-                        'packages from the branch and run tests against '
-                        'those, the test dependencies will be taken from the '
-                        'archive, or PPA if given. In this case the '
-                        'srcpkgname will only be used for the result path in '
-                        'swift and be irrelevant for the actual test.')
-    parser.add_argument('--build-git',
-                        metavar='URL [branchname]',
-                        help='A single URL or URL branchname. '
-                        'Like --test-git`, but will first build binary '
-                        'packages from the branch and run tests against those.')
-    parser.add_argument('--test-bzr',
-                        help='A single URL. '
-                        'The test will be checked out with bzr from that URL. '
-                        'Otherwise this has the same behaviour as test-git.')
-    parser.add_argument('--all-proposed', action='store_true',
-                        help='Disable apt pinning and use all of -proposed')
-    parser.add_argument('--bulk', action='store_true',
-                        help='Mark this as a bulk (low priority) test where possible')
-    parser.add_argument('package', nargs='+',
-                        help='Source package name(s) whose tests to run.')
-    args = parser.parse_args()
-
-    if not args.trigger and not args.ppa:
-        parser.error('One of --trigger or --ppa must be given')
-
-    # verify syntax of triggers
-    for t in args.trigger:
-        try:
-            (src, ver) = t.split('/')
-        except ValueError:
-            parser.error('Invalid trigger format "%s", must be "sourcepkg/version"' % t)
-
-    # verify syntax of PPAs
-    for t in args.ppa:
-        try:
-            (user, name) = t.split('/')
-        except ValueError:
-            parser.error('Invalid ppa format "%s", must be "lpuser/ppaname"' % t)
-
-    return args
-
-
-def parse_config(config_file):
-    '''Parse config file (like britney.py)'''
-
-    config = argparse.Namespace()
-    with open(config_file) as f:
-        for k, v in [r.split('=', 1) for r in f if '=' in r and not r.strip().startswith('#')]:
-            k = k.strip()
-            if not getattr(config, k.lower(), None):
-                setattr(config, k.lower(), v.strip())
-    return config
-
-
-if __name__ == '__main__':
-    args = parse_args()
-    britney_conf = os.path.join(my_dir, 'britney.conf')
-    if args.config:
-        config = parse_config(args.config)
-    elif os.path.exists(britney_conf + '.ubuntu.' + args.series):
-        config = parse_config(britney_conf + '.ubuntu.' + args.series)
-    else:
-        config = parse_config(britney_conf)
-    if not args.architecture:
-        args.architecture = config.adt_arches.split()
-
-    context = ''
-    params = {}
-    if args.bulk:
-        context = 'huge-'
-    if args.trigger:
-        params['triggers'] = args.trigger
-    if args.ppa:
-        params['ppas'] = args.ppa
-        context = 'ppa-'
-    if args.env:
-        params['env'] = args.env
-    if args.test_git:
-        params['test-git'] = args.test_git
-        context = 'upstream-'
-    elif args.build_git:
-        params['build-git'] = args.build_git
-        context = 'upstream-'
-    if args.test_bzr:
-        params['test-bzr'] = args.test_bzr
-        context = 'upstream-'
-    if args.all_proposed:
-        params['all-proposed'] = True
-    try:
-        params['requester'] = os.environ['SUDO_USER']
-    except KeyError:
-        pass
-    params['submit-time'] = datetime.strftime(datetime.utcnow(), '%Y-%m-%d %H:%M:%S%z')
-    params = '\n' + json.dumps(params)
-
-    creds = urllib.parse.urlsplit(config.adt_amqp, allow_fragments=False)
-    assert creds.scheme == 'amqp'
-
-    with amqp.Connection(creds.hostname, userid=creds.username,
-                         password=creds.password) as amqp_con:
-        with amqp_con.channel() as ch:
-            for arch in args.architecture:
-                queue = 'debci-%s%s-%s' % (context, args.series, arch)
-                for pkg in args.package:
-                    ch.basic_publish(amqp.Message(pkg + params,
-                                                  delivery_mode=2),  # persistent
-                                     routing_key=queue)

=== added file 'run-britney'
--- run-britney	1970-01-01 00:00:00 +0000
+++ run-britney	2019-04-20 00:23:18 +0000
@@ -0,0 +1,24 @@
+#! /bin/sh
+set -e
+
+if [ "$1" = --debug ]; then
+	REDIR=
+else
+	REDIR='>/dev/null 2>&1'
+fi
+
+# ubuntu-archive-reporting needs this
+bzr pull -q --overwrite -d "$HOME/packages-arch-specific"
+
+cd "$HOME/testing"
+if ! lockfile -r0 .run-britney.lock; then
+    exit 1
+fi
+trap "rm -f $HOME/testing/.run-britney.lock" EXIT HUP INT QUIT TERM
+eval ./britney merge stats $REDIR
+"$HOME/ubuntu-archive-reporting/outdate-report" >www/eoan_outdate_all.txt
+rsync -a --delete www/ "$HOME/public_html/testing/"
+
+cd "$HOME/testing-ports"
+eval ./britney merge stats $REDIR
+rsync -a --delete www/ "$HOME/public_html/testing-ports/"

=== removed file 'run-pm-notest'
--- run-pm-notest	2023-04-25 02:37:39 +0000
+++ run-pm-notest	1970-01-01 00:00:00 +0000
@@ -1,23 +0,0 @@
-#! /bin/sh
-set -e
-
-DEFAULT_SERIES=mantic
-
-export SERIES="${SERIES:-$DEFAULT_SERIES}"
-
-cd "$HOME/proposed-migration"
-[ -e STOP ] && exit 0
-if ! lockfile -r0 ".run-proposed-migration-ubuntu-$SERIES-notest.lock"; then
-	exit 1
-fi
-
-cleanup () {
-    rm -f $HOME/proposed-migration/.run-proposed-migration-ubuntu-$SERIES-notest.lock
-    [ -n "$tmpdir" ] && rm -rf "$tmpdir"
-}
-trap cleanup EXIT HUP INT QUIT TERM
-
-logfile="log/$SERIES/$(date -u +%F/%T).notest.log"
-mkdir -p "${logfile%/*}"
-
-code/b1/britney run_notest >"$logfile" 2>&1

=== modified file 'run-proposed-migration'
--- run-proposed-migration	2023-04-25 02:37:39 +0000
+++ run-proposed-migration	2019-10-04 16:35:20 +0000
@@ -11,7 +11,7 @@
 esac
 
 DEFAULT_DISTRIBUTION=ubuntu
-DEFAULT_SERIES=mantic
+DEFAULT_SERIES=eoan
 
 export DISTRIBUTION="${DISTRIBUTION:-$DEFAULT_DISTRIBUTION}"
 export SERIES="${SERIES:-$DEFAULT_SERIES}"
@@ -22,11 +22,11 @@
 fi
 
 case $DISTRIBUTION/$SERIES in
-    ubuntu/$DEFAULT_SERIES)
-	actions='hints_git blocks excuse_bugs pkglists run save stats'
+    ubuntu/$DEFAULT_SERIES|ubuntu-rtm/*)
+	actions='hints_bzr blocks excuse_bugs pkglists run save stats summary'
 	;;
     ubuntu/*)
-	actions='hints_git blocks excuse_bugs pkglists run stats'
+	actions='hints_bzr blocks excuse_bugs pkglists run stats summary'
 	;;
     *)
 	echo "Don't know what actions to run for $DISTRIBUTION/$SERIES!" >&2
@@ -45,24 +45,22 @@
     [ -n "$tmpdir" ] && rm -rf "$tmpdir"
 }
 trap cleanup EXIT HUP INT QUIT TERM
-http_proxy= bzr pull -q -d "$HOME/proposed-migration/code/b1"
+bzr pull -q -d "$HOME/proposed-migration/code/b1"
 (cd "$HOME/proposed-migration/code/b2"; git fetch origin; git reset --hard --quiet origin/master)
-http_proxy= bzr pull -q -d "$HOME/auto-package-testing"
+bzr pull -q -d "$HOME/auto-package-testing"
 logfile="log/$full_series/$(date -u +%F/%T).log"
 mkdir -p "${logfile%/*}"
 
 code/b1/britney $actions >"$logfile" 2>&1
 if [ "$SERIES" = "$DEFAULT_SERIES" ]; then
     cd ~/public_html/proposed-migration/
-    generate-team-p-m --excuses-yaml $SERIES/update_excuses.yaml.xz \
+    generate-team-p-m --excuses-yaml $SERIES/update_excuses.yaml \
                       --subscribers-json ~/public_html/package-team-mapping.json \
                       $SERIES/update_excuses_by_team.html $SERIES/update_excuses_by_team.yaml
     tmpdir="$(mktemp -d)"
     wget -q -O "$tmpdir/debian-excuses.yaml" https://release.debian.org/britney/excuses.yaml
-    find-rcbuggy-problem-packages --ubuntu-excuses $SERIES/update_excuses.yaml.xz \
+    find-rcbuggy-problem-packages --ubuntu-excuses $SERIES/update_excuses.yaml \
                                   --ubuntu-update_output $SERIES/update_output.txt \
                                   --debian-excuses "$tmpdir/debian-excuses.yaml" \
                                   --output $SERIES/rcbuggy-problem-packages.html
 fi
-
-exit 0

=== removed symlink 'sru-autosubscribe'
=== target was 'sru_autosubscribe.py'
=== removed file 'sru_autosubscribe.py'
--- sru_autosubscribe.py	2023-06-01 16:01:45 +0000
+++ sru_autosubscribe.py	1970-01-01 00:00:00 +0000
@@ -1,279 +0,0 @@
-#!/usr/bin/python3
-
-"""Subscribe uploaders to the unapproved queue to their SRU bugs
-
-Author: Robie Basak <robie.basak@canonical.com>
-
-Subscriptions are made on the principle that if you signed an upload, you need
-to follow up on review comments on the SRU team. The SRU team have been having
-trouble getting response to comments in bugs, noticed that often the sponsor
-isn't subscribed, and hopes this will help.
-
-This is intended to be run from a cronjob or timer. Run with --debug to see
-what is going on, and additionally with --dry-run to see what would happen.
-
-Principle of operation: get all key fingerprints of everyone in
-~ubuntu-uploaders. Then download the .dsc file from everything in Unapproved
-targetted at the proposed pockets of stable series and see who signed them.
-Then subscribe this person to all bugs referenced in Launchpad-Bugs-Fixed in
-the changes file of those uploads if they aren't subscribed at "Discussion"
-level already.
-
-To stop this script from acting on a particular bug, tag it "bot-stop-nagging".
-
-It takes a while to get going; hitting the Launchpad API for all uploaders'
-keys takes about a minute, then a further minute to fetch all the keys to get
-their subkey fingerprints from keyserver.ubuntu.com.
-
-All Ubuntu uploaders are supposed to be in ~ubuntu-uploaders but this isn't
-enforced except by the correct action of the DMB. If somebody has uploaded but
-is not a member of the team, this script will not find their key and therefore
-will not subscribe them to their bugs.
-
-The key 6309259455EFCAA8 also signs uploads and is ~ci-train-bot; it isn't a
-member of ~ubuntu-uploaders and is therefore also ignored. We don't have a way
-of identifying the actual sponsor in this case.
-"""
-
-import argparse
-import itertools
-import logging
-import re
-import subprocess
-import tempfile
-import urllib
-
-import debian.deb822
-import launchpadlib.launchpad
-
-GPG_OUTPUT_PATTERN = re.compile(
-    r"""gpg: Signature made.*
-gpg: +using (?:RSA|DSA) key (?P<fingerprint>[0-9A-F]+)
-"""
-)
-
-
-def find_specific_url(urls, suffix):
-    for url in urls:
-        if url.endswith(suffix):
-            return url
-    raise ValueError
-
-
-def get_upload_source_urls(upload):
-    if upload.contains_source:
-        return upload.sourceFileUrls()
-    elif upload.contains_copy:
-        try:
-            copy_source_archive = upload.copy_source_archive
-            # Trigger a problem ValueError exception now rather than later
-            # This is magic launchpadlib behaviour: accessing an attribute of
-            # copy_source_archive may fail later on an access permission issue
-            # due to lazy loading.
-            getattr(copy_source_archive, "self_link")
-        except ValueError as e:
-            raise RuntimeError(
-                f"Cannot access {upload} copy_source_archive attribute: no permission?"
-            ) from e
-        return next(
-            iter(
-                upload.copy_source_archive.getPublishedSources(
-                    source_name=upload.package_name,
-                    version=upload.package_version,
-                    exact_match=True,
-                    order_by_date=True,
-                )
-            )
-        ).sourceFileUrls()
-    else:
-        raise RuntimeError(f"Cannot find source for {upload}")
-
-
-def find_dsc_signing_fingerprint(dsc_url):
-    with urllib.request.urlopen(
-        dsc_url
-    ) as dsc_fobj, tempfile.TemporaryDirectory() as tmpdir:
-        result = subprocess.run(
-            ["gpg", "--verify"],
-            input=dsc_fobj.read(),
-            capture_output=True,
-            env={"GNUPGHOME": tmpdir},
-        )
-    if result.returncode != 2:
-        raise RuntimeError("Unknown exit status from gpg")
-    m = GPG_OUTPUT_PATTERN.search(result.stderr.decode())
-    if not m:
-        raise ValueError("Signing key fingerprint not found")
-    return m.group("fingerprint")
-
-
-def find_changes_bugs(changes_url):
-    with urllib.request.urlopen(changes_url) as changes_fobj:
-        changes = debian.deb822.Changes(changes_fobj)
-    try:
-        bugs_str = changes["Launchpad-Bugs-Fixed"]
-    except KeyError:
-        return []
-    return bugs_str.split()
-
-
-def ensure_subscribed(person, bug, dry_run):
-    for subscription in bug.subscriptions:
-        if (
-            subscription.person_link == person.self_link
-            and subscription.bug_notification_level == "Discussion"
-        ):
-            logging.debug(f"{person.name} is already subscribed to {bug.id}")
-            return
-    logging.debug(f"Subscribing {person.name} to {bug.id}")
-    if "bot-stop-nagging" in bug.tags:
-        logging.debug("bot-stop-nagging detected; not subscribing")
-        return
-    if not dry_run:
-        bug.subscribe(level="Discussion", person=person)
-
-
-def parse_fingerprints(output):
-    for line in output.decode().splitlines():
-        fields = line.split(":")
-        if fields[0] == "fpr":
-            yield fields[9]
-
-
-def fetch_subkey_fingerprints(primary_fingerprints):
-    with tempfile.TemporaryDirectory() as tmpdir:
-        for primary_fingerprint in primary_fingerprints:
-            logging.debug(f"Fetching key for {primary_fingerprint}")
-            result = subprocess.run(
-                [
-                    "gpg",
-                    "--keyserver",
-                    "keyserver.ubuntu.com",
-                    "--recv-key",
-                    primary_fingerprint,
-                ],
-                env={"GNUPGHOME": tmpdir},
-                capture_output=True,
-            )
-            if (
-                result.returncode == 2
-                and result.stderr == "gpg: keyserver receive failed: No data\n".encode()
-            ):
-                # Some keys cannot be fetched. See: https://irclogs.ubuntu.com/2022/09/07/%23launchpad.html#t14:03
-                continue
-            result.check_returncode()
-            result = subprocess.run(
-                [
-                    "gpg",
-                    "--list-keys",
-                    "--with-colons",
-                    "--with-fingerprint",
-                    "--with-fingerprint",  # duplicate to also give subkey fingerprints
-                    primary_fingerprint,
-                ],
-                env={"GNUPGHOME": tmpdir},
-                capture_output=True,
-                check=True,
-            )
-            yield primary_fingerprint, (
-                fpr
-                for fpr in parse_fingerprints(result.stdout)
-                if fpr != primary_fingerprint
-            )
-
-
-def determine_fingerprint_to_person_map(lp):
-    logging.debug("Fetching uploader key fingerprints")
-    fingerprint_to_person = {
-        gpg_key.fingerprint: person
-        for person, gpg_key in itertools.chain.from_iterable(
-            ((person, gpg_key) for gpg_key in person.gpg_keys)
-            for person in lp.people["ubuntu-uploaders"].participants
-        )
-    }
-    logging.debug(f"{len(fingerprint_to_person)} fingerprints fetched")
-
-    # Add subkey fingerprints
-    logging.debug(f"Retrieving subkey fingerprints from keyserver.ubuntu.com")
-    fingerprint_to_person.update(
-        {
-            subkey_fingerprint: fingerprint_to_person[primary_fingerprint]
-            for primary_fingerprint, subkey_fingerprint in itertools.chain.from_iterable(
-                (
-                    (primary_fingerprint, subkey_fingerprint)
-                    for subkey_fingerprint in subkey_fingerprints
-                )
-                for primary_fingerprint, subkey_fingerprints in fetch_subkey_fingerprints(
-                    fingerprint_to_person.keys()
-                )
-            )
-        }
-    )
-    logging.debug("Subkey fingerprints fetched")
-
-    # Some signers are only embedding 16 nibble keyids, so identify using these
-    # as well. It's easier to arrange collisions, but I think we can trust
-    # Ubuntu uploaders not to do this; and in the worst case scenario we'll
-    # only misidentify the uploader and give the wrong person the subscription
-    # anyway.
-    fingerprint_to_person.update(
-        {
-            fingerprint[-16:]: person
-            for fingerprint, person in fingerprint_to_person.items()
-        }
-    )
-    return fingerprint_to_person
-
-
-if __name__ == "__main__":
-    parser = argparse.ArgumentParser()
-    parser.add_argument("--dry-run", action="store_true")
-    parser.add_argument("--debug", action="store_true")
-    args = parser.parse_args()
-    if args.debug:
-        logging.basicConfig(level=logging.DEBUG)
-
-    lp = launchpadlib.launchpad.Launchpad.login_with(
-        "~racb sru_autosubscribe", "production", version="devel"
-    )
-
-    fingerprint_to_person = determine_fingerprint_to_person_map(lp)
-
-    distro_seriess = [
-        series
-        for series in lp.distributions["ubuntu"].series
-        if series.status in {"Current Stable Release", "Supported"}
-    ]
-    uploads = itertools.chain.from_iterable(
-        distro_series.getPackageUploads(pocket="Proposed", status="Unapproved")
-        for distro_series in distro_seriess
-    )
-    for upload in uploads:
-        logging.debug(f"Considering {upload}")
-        try:
-            urls = get_upload_source_urls(upload)
-        except RuntimeError:
-            logging.debug(f"Could not get source URLs for {upload}")
-            continue
-        try:
-            dsc_url = find_specific_url(urls, ".dsc")
-        except ValueError:
-            logging.debug(f"Could not find .dsc for {upload}")
-            continue
-        if not upload.changes_file_url:
-            logging.debug(f"Could not find changes file for {upload}")
-            continue
-        bug_numbers = find_changes_bugs(upload.changes_file_url)
-        fingerprint = find_dsc_signing_fingerprint(dsc_url)
-        try:
-            signer = fingerprint_to_person[fingerprint]
-        except KeyError:
-            logging.debug(f"Could not find signer with fingerprint {fingerprint}")
-            continue
-        for bug_number in bug_numbers:
-            try:
-                bug = lp.bugs[bug_number]
-            except KeyError:
-                logging.debug(f"Could not find bug {bug_number}")
-                continue
-            ensure_subscribed(person=signer, bug=bug, dry_run=args.dry_run)

=== removed file 'templates/team-report-bzr.html'
--- templates/team-report-bzr.html	2021-02-26 13:03:07 +0000
+++ templates/team-report-bzr.html	1970-01-01 00:00:00 +0000
@@ -1,38 +0,0 @@
-<!DOCTYPE HTML>
-<html>
-  <head>
-    <meta charset="utf-8">
-    <title>Bazaar packaging repositories by team</title>
-    <style>
-      body { font-family: ubuntu }
-      .not-late { color: grey; }
-      .not-late a { color: #77f; }
-    </style>
-  </head>
-  <body lang="en">
-    <h1>Bazaar packaging repositories by team</h1>
-    <p>Git migration tools and schedule: <a href="https://wiki.ubuntu.com/UbuntuDevelopment/MigratingFromBzrToGit">https://wiki.ubuntu.com/UbuntuDevelopment/MigratingFromBzrToGit</a></p>
-    <p>
-      Generated: {{ now }}
-    <ul>
-      {% for team in all_teams|sort %}
-      <li><a href="#{{ team }}">{{ team }}</a> ({{ ngettext("%(num)d packaging repository", "%(num)d packaging repositories", team_to_attn_count[team]) }})</li>
-      {% endfor %}
-    </ul>
-    {% for team in all_teams|sort %}
-    <h1 id="{{ team }}">{{ team }}</h1>
-    <p>
-      {{ ngettext("%(num)d packaging repositories", "%(num)d packaging repositories", team_to_attn_count[team]) }}
-    </p>
-    <ul>
-      {% for pkg in team_to_pkgs[team] %}
-      {% set p = pkg[0] %}
-      {% set url = pkg[1] %}
-      <li>
-        <b><a href="https://launchpad.net/ubuntu/+source/{{ p }}/">{{ p }}</a>:</b> <a href="{{ url }}">{{ url }}</a>
-      </li>
-      {% endfor %}
-    </ul>
-    {% endfor %}
-  </body>
-</html>

=== modified file 'templates/team-report.html'
--- templates/team-report.html	2023-04-03 19:40:08 +0000
+++ templates/team-report.html	2019-04-08 23:02:19 +0000
@@ -30,9 +30,9 @@
       <li {% if not prob.late %}class="not-late"{% endif %}>
         {% if prob.kind == "regressing-other" %}
         <b>{{ prob.regressing_package }}</b> blocking
-        <a href="https://ubuntu-archive-team.ubuntu.com/proposed-migration/update_excuses.html#{{ p }}">{{ p }}</a>
+        <a href="http://people.canonical.com/~ubuntu-archive/proposed-migration/update_excuses.html#{{ p }}">{{ p }}</a>
         {% else %}
-        <a href="https://ubuntu-archive-team.ubuntu.com/proposed-migration/update_excuses.html#{{ p }}"><b>{{ p }}</b></a>
+        <a href="http://people.canonical.com/~ubuntu-archive/proposed-migration/update_excuses.html#{{ p }}"><b>{{ p }}</b></a>
         {% endif %}
         {% set urlbase = "https://launchpad.net/ubuntu/+source/" + p + "/" %}
         ({% if d['old-version'] != "-" %}<a href="{{ urlbase }}{{ d["old-version"] }}">{{ d["old-version"] }}{% else %}-{% endif %}</a>
@@ -43,20 +43,8 @@
         {% else %}
         in proposed for
         {% endif %}
-        {% if prob.age == -1 %}
-        an unknown number of days
-        {% else %}
         {{ ngettext("%(num)d day", "%(num)d days", prob.age|int) }}
-        {% endif %}
         <ul>
-          {% if d["policy_info"]["update-excuse"] %}
-          <li>Excuses bugs:
-          {% for bug in d["policy_info"]["update-excuse"]|map("int")|sort|map("string") %}
-          <a href="https://bugs.launchpad.net/bugs/{{ bug }}">#{{ bug }}</a>
-          {%- if not loop.last %}, {% endif %}
-          {% endfor %}
-          </li>
-          {% endif %}
           {% if d.get("missing-builds") %}
           <li>Missing builds, see excuses</li>
           {% endif %}
@@ -103,62 +91,17 @@
             </ul>
           </li>
           {% endif %}
-          {% if prob.unsatbuilddep %}
-          <li>
-            Unsatisfiable build depends:
-            <ul>
-              {% for unsatbd in prob.unsatbuilddep %}
-              <li>{{ unsatbd }}</li>
-              {% endfor %}
-            </ul>
-          </li>
-          {% endif %}
-          {% if prob.brokenbin %}
-          <li>Binaries broken by the update: {{ prob.brokenbin | join(' ') }}</li>
-          {% endif %}
-          {% if prob.componentmismatch %}
-          <li>
-            Component mismatch entries
-            <ul>
-              {% for component in prob.componentmismatch %}
-              <li> {{ component }} </li>
-              {% endfor %}
-            </ul>
-          </li>
-          {% endif %}
           {% if d["policy_info"]["block-bugs"] %}
           <li>Blocked by bug:
           {% for bug in d["policy_info"]["block-bugs"]|map("int")|sort|map("string") %}
           <a href="https://bugs.launchpad.net/bugs/{{ bug }}">#{{ bug }}</a>
           {%- if not loop.last %}, {% endif %}
           {% endfor %}
-          </li>
-          {% endif %}
-          {% if d["hints"] %}
-          {% for hint in d["hints"] %}
-          {% if hint["hint-type"] %}
-          {% if hint["hint-type"] == "block" %}
-          <li>Blocked by hint
-          {% if hint["hint-from"] %}
-          from {{ hint["hint-from"] }}
-          {% endif %}
-          </li>
-          {% endif %}
-          {% endif %}
-          {% endfor %}
           {% endif %}
           {% if d["is-candidate"] %}
           <li><b>candidate</b></li>
           {% endif %}
           {% endif %}
-          {% if d.get('dependencies', {}).get('migrate-after', []) %}
-          <li>Requires 
-          {% for depmigrate in d.get('dependencies', {}).get('migrate-after', []) %}
-          <a href="https://ubuntu-archive-team.ubuntu.com/proposed-migration/update_excuses.html#{{ depmigrate }}">{{ depmigrate }}</a>
-          {%- if not loop.last %}, {% endif %}
-          {% endfor %}
-          to migrate</li>
-          {% endif %}
         </ul>
       </li>
       {% endfor %}

=== modified file 'update-germinate'
--- update-germinate	2023-04-25 02:37:39 +0000
+++ update-germinate	2019-04-20 00:23:18 +0000
@@ -4,94 +4,54 @@
 
 (cd "$HOME/germinate" && git pull -q)
 
-export GERMINATE_OPTIONS
-options_for_dist() {
-	case $1 in
-		trusty|xenial|bionic)
-			GERMINATE_OPTIONS="-a i386"
-			;;
-		*)
-			GERMINATE_OPTIONS="-a amd64"
-			;;
-	esac
-}
-
-for dist in trusty xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial bionic cosmic disco eoan; do
 	update-one-germinate "ubuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial bionic cosmic disco eoan; do
 	update-one-germinate "kubuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial; do
 	update-one-germinate "edubuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial bionic cosmic disco eoan; do
 	update-one-germinate "xubuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial bionic cosmic disco eoan; do
 	update-one-germinate "ubuntustudio.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial; do
 	update-one-germinate "mythbuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty; do
-	options_for_dist "$dist"
+for dist in precise trusty; do
 	update-one-germinate "kubuntu-active.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in trusty xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in precise trusty xenial bionic cosmic disco eoan; do
 	update-one-germinate "lubuntu.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in lunar mantic; do
-	options_for_dist "$dist"
-	update-one-germinate "ubuntucinnamon.$dist" "$dist" main,restricted,universe,multiverse
-done
-
 for dist in trusty xenial; do
-	options_for_dist "$dist"
 	update-one-germinate "ubuntu-gnome.$dist" "$dist" main,restricted,universe,multiverse
 done
 
 for dist in trusty xenial; do
-	options_for_dist "$dist"
 	update-one-germinate "ubuntu-touch.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in xenial bionic cosmic disco eoan; do
 	update-one-germinate "ubuntukylin.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in xenial bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in xenial bionic cosmic disco eoan; do
 	update-one-germinate "ubuntu-mate.$dist" "$dist" main,restricted,universe,multiverse
 done
 
-for dist in bionic focal jammy kinetic lunar mantic; do
-	options_for_dist "$dist"
+for dist in bionic cosmic disco eoan; do
 	update-one-germinate "ubuntu-budgie.$dist" "$dist" main,restricted,universe,multiverse
 done
-
-for dist in kinetic lunar mantic; do
-	options_for_dist "$dist"
-	update-one-germinate "ubuntu-unity.$dist" "$dist" main,restricted,universe,multiverse
-done
-
-for dist in focal jammy kinetic lunar mantic; do
-	GERMINATE_OPTIONS="-a i386" \
-	update-one-germinate "i386.$dist" "$dist" main,restricted,universe,multiverse
-done

=== modified file 'update-one-germinate'
--- update-one-germinate	2023-05-27 19:14:20 +0000
+++ update-one-germinate	2013-09-16 14:11:34 +0000
@@ -14,12 +14,9 @@
 rm -rf "$HOME/public_html/germinate-output/$NAME.new"
 mkdir -p "$HOME/public_html/germinate-output/$NAME.new"
 cd "$HOME/public_html/germinate-output/$NAME.new"
-python3 "$HOME/germinate/bin/germinate" $GERMINATE_OPTIONS ${SEED_SOURCE:+-S "$SEED_SOURCE"} -m file:///home/ubuntu-archive/mirror/ubuntu -s "$NAME" -d "$DIST" ${COMPONENTS:+-c "$COMPONENTS"} > _germinate_output
+python "$HOME/germinate/bin/germinate" $GERMINATE_OPTIONS ${SEED_SOURCE:+-S "$SEED_SOURCE"} -m file:///home/ubuntu-archive/mirror/ubuntu -s "$NAME" -d "$DIST" ${COMPONENTS:+-c "$COMPONENTS"} > _germinate_output
 cd ..
 rm -rf "$NAME.old"
-if [ -e "$NAME" ]; then
-	diff -uNr "$NAME" "$NAME.new" | (cd "$NAME" && patch -p1)
-	rm -rf "$NAME.new"
-else
-	mv "$NAME.new" "$NAME"
-fi
+[ -e "$NAME" ] && mv "$NAME" "$NAME.old"
+mv "$NAME.new" "$NAME"
+rm -rf "$NAME.old"

=== modified file 'update-seeds'
--- update-seeds	2023-04-25 02:37:39 +0000
+++ update-seeds	2019-04-20 00:23:18 +0000
@@ -9,24 +9,22 @@
 
 ONLY_SERIES="$1"
 
-for dist in platform.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            ubuntu.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            kubuntu.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            kubuntu-active.trusty \
-            edubuntu.{lunar,mantic} \
-            xubuntu.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            i386.{focal,jammy,kinetic,lunar,mantic} \
-            mythbuntu.{trusty,xenial} \
-            ubuntustudio.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            lubuntu.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
+for dist in platform.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
+            ubuntu.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
+            kubuntu.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
+            kubuntu-active.{precise,trusty} \
+            edubuntu.{precise,trusty,xenial} \
+            xubuntu.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
+            netbook.precise \
+            mythbuntu.{precise,trusty,xenial} \
+            ubuntustudio.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
+            lubuntu.{precise,trusty,xenial,bionic,cosmic,disco,eoan} \
             ubuntu-gnome.xenial \
             ubuntu-touch.{trusty,xenial} \
-            ubuntukylin.{trusty,xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            ubuntucinnamon.{lunar,mantic} \
-            ubuntu-core.{xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            ubuntu-mate.{xenial,bionic,focal,jammy,kinetic,lunar,mantic} \
-            ubuntu-budgie.{bionic,focal,jammy,kinetic,lunar,mantic} \
-            ubuntu-unity.{kinetic,lunar,mantic}; do
+            ubuntukylin.{trusty,xenial,bionic,cosmic,disco,eoan} \
+            ubuntu-core.{xenial,bionic,cosmic,disco,eoan} \
+            ubuntu-mate.{xenial,bionic,cosmic,disco,eoan} \
+            ubuntu-budgie.{bionic,cosmic,disco,eoan}; do
 	if [ "$ONLY_SERIES" ]; then
 		case $dist in
 			*.$ONLY_SERIES)
@@ -38,13 +36,7 @@
 	fi
 
 	case $dist in
-		edubuntu.*)
-			branch="https://git.launchpad.net/~edubuntu-dev/ubuntu-seeds/+git/edubuntu"
-			;;
-		kubuntu.*)
-			branch="https://git.launchpad.net/~kubuntu-dev/ubuntu-seeds/+git/kubuntu"
-			;;
-		kubuntu-active.*)
+		kubuntu.*|kubuntu-active.*|kubuntu-plasma5.*)
 			branch="http://bazaar.launchpad.net/~kubuntu-dev/ubuntu-seeds/$dist"
 			;;
 		xubuntu.*)
@@ -71,12 +63,6 @@
 		ubuntu-budgie.*)
 			branch="http://bazaar.launchpad.net/~ubuntubudgie-dev/ubuntu-seeds/$dist"
 			;;
-		ubuntucinnamon.*)
-			branch="https://git.launchpad.net/~ubuntucinnamon-dev/ubuntu-seeds/+git/ubuntucinnamon"
-			;;
-		ubuntu-unity.*)
-			branch="https://git.launchpad.net/~unity7maintainers/ubuntu-seeds/+git/ubuntu-unity"
-			;;
 		*)
 			branch="https://git.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/+git/${dist%.*}"
 			;;
@@ -93,13 +79,13 @@
 		if [ -n "$git" ]; then
 			git -C "$dist" pull -f >/dev/null 2>&1
 		else
-			http_proxy= bzr pull -d "$dist" --overwrite --remember "$branch" >/dev/null 2>&1
+			bzr pull -d "$dist" --overwrite --remember "$branch" >/dev/null 2>&1
 		fi
 	else
 		if [ -n "$git" ]; then
 			git clone -b "$(echo $dist | sed 's/.*\.//')" "$branch" "$dist" >/dev/null 2>&1
 		else
-			http_proxy= bzr branch "$branch" >/dev/null 2>&1
+			bzr branch "$branch" >/dev/null 2>&1
 		fi
 	fi
 done

=== renamed file 'update-sync-blocklist' => 'update-sync-blacklist'
--- update-sync-blocklist	2023-07-05 14:37:23 +0000
+++ update-sync-blacklist	2012-11-12 00:26:03 +0000
@@ -1,10 +1,10 @@
 #! /bin/sh
 set -e
 
-BRANCH="$HOME/sync-blocklist"
-SOURCE="$BRANCH/sync-blocklist.txt"
-DESTINATION="$HOME/public_html/sync-blocklist.txt"
+BRANCH="$HOME/sync-blacklist"
+SOURCE="$BRANCH/sync-blacklist.txt"
+DESTINATION="$HOME/public_html/sync-blacklist.txt"
 
-git -C "$BRANCH" pull -q
+bzr pull -q --overwrite -d "$BRANCH"
 cp -a "$SOURCE" "$DESTINATION.new"
 mv "$DESTINATION.new" "$DESTINATION"

=== modified file 'update-transitions'
--- update-transitions	2022-04-19 17:02:10 +0000
+++ update-transitions	2013-11-05 14:50:40 +0000
@@ -1,11 +1,5 @@
 #! /bin/sh
 set -e
 
-# This could run as 1000/1000 , but for some reason it outputs
-# Fatal error: exception Not_found
-# If debugged, we could do the below instead, but for now the 'go' script runs
-# as root and chmods its output to ubuntu:ubuntu (inside the chroot, which maps
-# to ubuntu-archive outside)
-
-# lxc exec --user 1000 --group 1000 ben -- /srv/transitions/transition-tracker/config/go
-flock -xn -E 0 ~/.update-transitions.lock lxc exec ben -- sudo -u ubuntu /srv/transitions/transition-tracker/config/go
+schroot -c trusty-transitions -d "$HOME" /srv/transitions/transition-tracker/go
+rsync -aq --delete-after --delete /srv/chroots/trusty-transitions/srv/transitions/www/ "$HOME/public_html/transitions/"

